@@ -1,7 +1,7 @@
-"""Value model."""
+"""Provide a model for the Z-Wave JS value."""
+from typing import TYPE_CHECKING, Any, Optional
 
-
-from typing import Any, Optional, TYPE_CHECKING
+from ..event import Event
 
 if TYPE_CHECKING:
     from .node import Node
@@ -16,7 +16,10 @@ def value_id(node: "Node", event: dict) -> str:
 
 
 class ValueMetadata:
-    def __init__(self, data) -> None:
+    """Represent metadata on a value instance."""
+
+    def __init__(self, data: dict) -> None:
+        """Initialize metadata."""
         self.data = data
 
     @property
@@ -61,7 +64,10 @@ class ValueMetadata:
 
 
 class Value:
+    """Represent a Z-Wave JS value."""
+
     def __init__(self, node: "Node", data: dict) -> None:
+        """Initialize value."""
         self.node = node
         self.data = data
         self._value = data.get("value")
@@ -116,10 +122,7 @@ class Value:
         """Return propertyKeyName."""
         return self.data.get("propertyKeyName")
 
-    def receive_event(self, event: dict):
+    def receive_event(self, event: Event) -> None:
         """Receive an event."""
-        if event["event"] != "value updated":
-            return
-
-        self.data.update(event["args"])
-        self._value = event["args"].get("newValue")
+        self.data.update(event.data["args"])
+        self._value = event.data["args"].get("newValue")
